@@ -1351,7 +1351,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	{
 		if(!ScriptChecks::useKeywords(line, 
 			"=reconnect=peering=secret=encoding=framing=dtmf=user=count=device"
-			"=info=answer=accept=hold=transfer=update"))
+			"=info=answer=accept=hold=transfer=update=group"))
 				return "invalid keywords used for sip external";
 	}
 	else if(!ScriptChecks::useKeywords(line, 
@@ -1378,8 +1378,12 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->update = ScriptChecks::findKeyword(line, "update");
 	reg->hold = ScriptChecks::findKeyword(line, "hold");
 	reg->transfer = ScriptChecks::findKeyword(line, "transfer");
+	reg->group = ScriptChecks::findKeyword(line, "group");
 	gateways = ScriptChecks::findKeyword(line, "gateways");
 	
+	if(!reg->group)
+		reg->group = "nobody";
+
 	cp = ScriptChecks::findKeyword(line, "accept");
 	if(cp)
 		reg->accept = atol(cp);
@@ -1432,7 +1436,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	cp = ScriptChecks::findKeyword(line, "device");
 	if(cp)
 	{
-		snprintf(buf, sizeof(buf), "/bayonne/sipdevice/%s", cp);
+		snprintf(buf, sizeof(buf), "/bayonne/device/%s", cp);
 		cfg = new Keydata(buf);
 	}
 
@@ -2958,7 +2962,10 @@ sip480:
 					session->setEncoding(reg->encoding, reg->framing);
 
 				if(!strnicmp(reg->type, "ext", 3))
+				{
 					session->setConst("session.identity", reg->localid);
+					session->setConst("session.group", reg->group);
+				}
 				else
 					session->setConst("session.service", reg->service);
 			
