@@ -21,6 +21,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <grp.h>
+#include <sys/stat.h>
 #include "private.h"
 
 static char btspaths[] = CONFIG_FILES "/server.conf";
@@ -76,8 +77,7 @@ static void libexec_parse(void)
 	fflush(stdout);
 	for(;;)
 	{
-		fgets(lbuf, sizeof(lbuf), stdin);
-		if(feof(stdin))
+		if(!fgets(lbuf, sizeof(lbuf), stdin) || feof(stdin))
 			break;
 		if(!isalnum(lbuf[0]))
 			break;
@@ -99,8 +99,7 @@ static void libexec_parse(void)
 	fflush(stdout);
 	for(;;)
 	{
-		fgets(lbuf, sizeof(lbuf), stdin);
-		if(feof(stdin))
+		if(!fgets(lbuf, sizeof(lbuf), stdin) || feof(stdin))
 			break;
 		if(!isalnum(lbuf[0]))
 			break;
@@ -151,8 +150,7 @@ int main(int argc, char **argv)
 
 	for(;;)
 	{
-		fgets(lbuf, sizeof(lbuf), fp);
-		if(feof(fp))
+		if(!fgets(lbuf, sizeof(lbuf), fp) || feof(fp))
 		{
 			fclose(fp);
 			goto launch;
@@ -175,8 +173,7 @@ int main(int argc, char **argv)
 	}
 	for(;;)
 	{
-		fgets(lbuf, sizeof(lbuf), fp);
-		if(feof(fp))
+		if(!fgets(lbuf, sizeof(lbuf), fp) || feof(fp))
 			break;
 
 		cp = lbuf;
